@@ -44,6 +44,7 @@ typedef enum {
 	FWUPD_STATUS_WAITING_FOR_AUTH, /* Since: 1.0.0 */
 	FWUPD_STATUS_DEVICE_BUSY,      /* Since: 1.0.1 */
 	FWUPD_STATUS_SHUTDOWN,	       /* Since: 1.2.1 */
+	FWUPD_STATUS_WAITING_FOR_USER, /* Since: 1.9.8 */
 	/*< private >*/
 	FWUPD_STATUS_LAST
 } FwupdStatus;
@@ -76,6 +77,7 @@ typedef enum {
  * @FWUPD_FEATURE_FLAG_COMMUNITY_TEXT:		Can show information about community supported
  * @FWUPD_FEATURE_FLAG_SHOW_PROBLEMS:		Can show problems when getting the update list
  * @FWUPD_FEATURE_FLAG_ALLOW_AUTHENTICATION:	Can authenticate with PolicyKit for requests
+ * @FWUPD_FEATURE_FLAG_REQUESTS_NON_GENERIC:	Can handle showing non-generic request message text
  *
  * The flags to the feature capabilities of the front-end client.
  **/
@@ -90,6 +92,7 @@ typedef enum {
 	FWUPD_FEATURE_FLAG_COMMUNITY_TEXT = 1 << 6,	  /* Since: 1.7.5 */
 	FWUPD_FEATURE_FLAG_SHOW_PROBLEMS = 1 << 7,	  /* Since: 1.8.1 */
 	FWUPD_FEATURE_FLAG_ALLOW_AUTHENTICATION = 1 << 8, /* Since: 1.8.4 */
+	FWUPD_FEATURE_FLAG_REQUESTS_NON_GENERIC = 1 << 9, /* Since: 1.9.8 */
 	/*< private >*/
 	FWUPD_FEATURE_FLAG_LAST
 } FwupdFeatureFlags;
@@ -109,7 +112,7 @@ typedef enum {
  *
  * Since 0.1.3
  */
-#define FWUPD_DEVICE_FLAG_INTERNAL (1llu << 0)
+#define FWUPD_DEVICE_FLAG_INTERNAL (1ull << 0)
 /**
  * FWUPD_DEVICE_FLAG_UPDATABLE:
  *
@@ -117,7 +120,7 @@ typedef enum {
  *
  * Since 0.9.7
  */
-#define FWUPD_DEVICE_FLAG_UPDATABLE (1llu << 1)
+#define FWUPD_DEVICE_FLAG_UPDATABLE (1ull << 1)
 /**
  * FWUPD_DEVICE_FLAG_ONLY_OFFLINE:
  *
@@ -125,7 +128,7 @@ typedef enum {
  *
  * Since 0.9.7
  */
-#define FWUPD_DEVICE_FLAG_ONLY_OFFLINE (1llu << 2)
+#define FWUPD_DEVICE_FLAG_ONLY_OFFLINE (1ull << 2)
 /**
  * FWUPD_DEVICE_FLAG_REQUIRE_AC:
  *
@@ -134,7 +137,7 @@ typedef enum {
  *
  * Since 0.6.3
  */
-#define FWUPD_DEVICE_FLAG_REQUIRE_AC (1llu << 3)
+#define FWUPD_DEVICE_FLAG_REQUIRE_AC (1ull << 3)
 /**
  * FWUPD_DEVICE_FLAG_LOCKED:
  *
@@ -142,7 +145,7 @@ typedef enum {
  *
  * Since 0.6.3
  */
-#define FWUPD_DEVICE_FLAG_LOCKED (1llu << 4)
+#define FWUPD_DEVICE_FLAG_LOCKED (1ull << 4)
 /**
  * FWUPD_DEVICE_FLAG_SUPPORTED:
  *
@@ -150,7 +153,7 @@ typedef enum {
  *
  * Since 0.7.1
  */
-#define FWUPD_DEVICE_FLAG_SUPPORTED (1llu << 5)
+#define FWUPD_DEVICE_FLAG_SUPPORTED (1ull << 5)
 /**
  * FWUPD_DEVICE_FLAG_NEEDS_BOOTLOADER:
  *
@@ -158,7 +161,7 @@ typedef enum {
  *
  * Since 0.7.3
  */
-#define FWUPD_DEVICE_FLAG_NEEDS_BOOTLOADER (1llu << 6)
+#define FWUPD_DEVICE_FLAG_NEEDS_BOOTLOADER (1ull << 6)
 /**
  * FWUPD_DEVICE_FLAG_REGISTERED:
  *
@@ -166,7 +169,7 @@ typedef enum {
  *
  * Since 0.9.7
  */
-#define FWUPD_DEVICE_FLAG_REGISTERED (1llu << 7)
+#define FWUPD_DEVICE_FLAG_REGISTERED (1ull << 7)
 /**
  * FWUPD_DEVICE_FLAG_NEEDS_REBOOT:
  *
@@ -174,7 +177,7 @@ typedef enum {
  *
  * Since 0.9.7
  */
-#define FWUPD_DEVICE_FLAG_NEEDS_REBOOT (1llu << 8)
+#define FWUPD_DEVICE_FLAG_NEEDS_REBOOT (1ull << 8)
 /**
  * FWUPD_DEVICE_FLAG_REPORTED:
  *
@@ -182,7 +185,7 @@ typedef enum {
  *
  * Since: 1.0.4
  */
-#define FWUPD_DEVICE_FLAG_REPORTED (1llu << 9)
+#define FWUPD_DEVICE_FLAG_REPORTED (1ull << 9)
 /**
  * FWUPD_DEVICE_FLAG_NOTIFIED:
  *
@@ -190,7 +193,7 @@ typedef enum {
  *
  * Since: 1.0.5
  */
-#define FWUPD_DEVICE_FLAG_NOTIFIED (1llu << 10)
+#define FWUPD_DEVICE_FLAG_NOTIFIED (1ull << 10)
 /**
  * FWUPD_DEVICE_FLAG_USE_RUNTIME_VERSION:
  *
@@ -198,7 +201,7 @@ typedef enum {
  *
  * Since: 1.0.6
  */
-#define FWUPD_DEVICE_FLAG_USE_RUNTIME_VERSION (1llu << 11)
+#define FWUPD_DEVICE_FLAG_USE_RUNTIME_VERSION (1ull << 11)
 /**
  * FWUPD_DEVICE_FLAG_INSTALL_PARENT_FIRST:
  *
@@ -207,7 +210,7 @@ typedef enum {
  *
  * Since: 1.0.8
  */
-#define FWUPD_DEVICE_FLAG_INSTALL_PARENT_FIRST (1llu << 12)
+#define FWUPD_DEVICE_FLAG_INSTALL_PARENT_FIRST (1ull << 12)
 /**
  * FWUPD_DEVICE_FLAG_IS_BOOTLOADER:
  *
@@ -215,7 +218,7 @@ typedef enum {
  *
  * Since: 1.0.8
  */
-#define FWUPD_DEVICE_FLAG_IS_BOOTLOADER (1llu << 13)
+#define FWUPD_DEVICE_FLAG_IS_BOOTLOADER (1ull << 13)
 /**
  * FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG:
  *
@@ -223,7 +226,7 @@ typedef enum {
  *
  * Since: 1.1.2
  */
-#define FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG (1llu << 14)
+#define FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG (1ull << 14)
 /**
  * FWUPD_DEVICE_FLAG_IGNORE_VALIDATION:
  *
@@ -231,7 +234,7 @@ typedef enum {
  *
  * Since: 1.1.2
  */
-#define FWUPD_DEVICE_FLAG_IGNORE_VALIDATION (1llu << 15)
+#define FWUPD_DEVICE_FLAG_IGNORE_VALIDATION (1ull << 15)
 /**
  * FWUPD_DEVICE_FLAG_TRUSTED:
  *
@@ -240,7 +243,7 @@ typedef enum {
  *
  * Since: 1.1.2
  */
-#define FWUPD_DEVICE_FLAG_TRUSTED (1llu << 16)
+#define FWUPD_DEVICE_FLAG_TRUSTED (1ull << 16)
 /**
  * FWUPD_DEVICE_FLAG_NEEDS_SHUTDOWN:
  *
@@ -248,7 +251,7 @@ typedef enum {
  *
  * Since: 1.2.4
  */
-#define FWUPD_DEVICE_FLAG_NEEDS_SHUTDOWN (1llu << 17)
+#define FWUPD_DEVICE_FLAG_NEEDS_SHUTDOWN (1ull << 17)
 /**
  * FWUPD_DEVICE_FLAG_ANOTHER_WRITE_REQUIRED:
  *
@@ -256,7 +259,7 @@ typedef enum {
  *
  * Since: 1.2.5
  */
-#define FWUPD_DEVICE_FLAG_ANOTHER_WRITE_REQUIRED (1llu << 18)
+#define FWUPD_DEVICE_FLAG_ANOTHER_WRITE_REQUIRED (1ull << 18)
 /**
  * FWUPD_DEVICE_FLAG_NO_AUTO_INSTANCE_IDS:
  *
@@ -265,7 +268,7 @@ typedef enum {
  * Since: 1.2.5
  * Deprecated 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_NO_AUTO_INSTANCE_IDS (1llu << 19)
+#define FWUPD_DEVICE_FLAG_NO_AUTO_INSTANCE_IDS (1ull << 19)
 /**
  * FWUPD_DEVICE_FLAG_NEEDS_ACTIVATION:
  *
@@ -275,7 +278,7 @@ typedef enum {
  *
  * Since: 1.2.6
  */
-#define FWUPD_DEVICE_FLAG_NEEDS_ACTIVATION (1llu << 20)
+#define FWUPD_DEVICE_FLAG_NEEDS_ACTIVATION (1ull << 20)
 /**
  * FWUPD_DEVICE_FLAG_ENSURE_SEMVER:
  *
@@ -284,7 +287,7 @@ typedef enum {
  * Since: 1.2.9
  * Deprecate: 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_ENSURE_SEMVER (1llu << 21)
+#define FWUPD_DEVICE_FLAG_ENSURE_SEMVER (1ull << 21)
 /**
  * FWUPD_DEVICE_FLAG_HISTORICAL:
  *
@@ -292,7 +295,7 @@ typedef enum {
  *
  * Since: 1.3.2
  */
-#define FWUPD_DEVICE_FLAG_HISTORICAL (1llu << 22)
+#define FWUPD_DEVICE_FLAG_HISTORICAL (1ull << 22)
 /**
  * FWUPD_DEVICE_FLAG_ONLY_SUPPORTED:
  *
@@ -301,7 +304,7 @@ typedef enum {
  * Since: 1.3.3
  * Deprecated 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_ONLY_SUPPORTED (1llu << 23)
+#define FWUPD_DEVICE_FLAG_ONLY_SUPPORTED (1ull << 23)
 /**
  * FWUPD_DEVICE_FLAG_WILL_DISAPPEAR:
  *
@@ -310,7 +313,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_WILL_DISAPPEAR (1llu << 24)
+#define FWUPD_DEVICE_FLAG_WILL_DISAPPEAR (1ull << 24)
 /**
  * FWUPD_DEVICE_FLAG_CAN_VERIFY:
  *
@@ -318,7 +321,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_CAN_VERIFY (1llu << 25)
+#define FWUPD_DEVICE_FLAG_CAN_VERIFY (1ull << 25)
 /**
  * FWUPD_DEVICE_FLAG_CAN_VERIFY_IMAGE:
  *
@@ -326,7 +329,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_CAN_VERIFY_IMAGE (1llu << 26)
+#define FWUPD_DEVICE_FLAG_CAN_VERIFY_IMAGE (1ull << 26)
 /**
  * FWUPD_DEVICE_FLAG_DUAL_IMAGE:
  *
@@ -335,7 +338,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_DUAL_IMAGE (1llu << 27)
+#define FWUPD_DEVICE_FLAG_DUAL_IMAGE (1ull << 27)
 /**
  * FWUPD_DEVICE_FLAG_SELF_RECOVERY:
  *
@@ -344,7 +347,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_SELF_RECOVERY (1llu << 28)
+#define FWUPD_DEVICE_FLAG_SELF_RECOVERY (1ull << 28)
 /**
  * FWUPD_DEVICE_FLAG_USABLE_DURING_UPDATE:
  *
@@ -353,7 +356,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_USABLE_DURING_UPDATE (1llu << 29)
+#define FWUPD_DEVICE_FLAG_USABLE_DURING_UPDATE (1ull << 29)
 /**
  * FWUPD_DEVICE_FLAG_VERSION_CHECK_REQUIRED:
  *
@@ -361,7 +364,7 @@ typedef enum {
  *
  * Since: 1.3.7
  */
-#define FWUPD_DEVICE_FLAG_VERSION_CHECK_REQUIRED (1llu << 30)
+#define FWUPD_DEVICE_FLAG_VERSION_CHECK_REQUIRED (1ull << 30)
 /**
  * FWUPD_DEVICE_FLAG_INSTALL_ALL_RELEASES:
  *
@@ -369,7 +372,7 @@ typedef enum {
  *
  * Since: 1.3.7
  */
-#define FWUPD_DEVICE_FLAG_INSTALL_ALL_RELEASES (1llu << 31)
+#define FWUPD_DEVICE_FLAG_INSTALL_ALL_RELEASES (1ull << 31)
 /**
  * FWUPD_DEVICE_FLAG_MD_SET_NAME:
  *
@@ -378,7 +381,7 @@ typedef enum {
  * Since: 1.4.0
  * Deprecated 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_MD_SET_NAME (1llu << 32)
+#define FWUPD_DEVICE_FLAG_MD_SET_NAME (1ull << 32)
 /**
  * FWUPD_DEVICE_FLAG_MD_SET_NAME_CATEGORY:
  *
@@ -387,7 +390,7 @@ typedef enum {
  * Since: 1.4.0
  * Deprecated 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_MD_SET_NAME_CATEGORY (1llu << 33)
+#define FWUPD_DEVICE_FLAG_MD_SET_NAME_CATEGORY (1ull << 33)
 /**
  * FWUPD_DEVICE_FLAG_MD_SET_VERFMT:
  *
@@ -396,7 +399,7 @@ typedef enum {
  * Since: 1.4.0
  * Deprecated 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_MD_SET_VERFMT (1llu << 34)
+#define FWUPD_DEVICE_FLAG_MD_SET_VERFMT (1ull << 34)
 /**
  * FWUPD_DEVICE_FLAG_ADD_COUNTERPART_GUIDS:
  *
@@ -405,7 +408,7 @@ typedef enum {
  *
  * Since: 1.4.0
  */
-#define FWUPD_DEVICE_FLAG_ADD_COUNTERPART_GUIDS (1llu << 35)
+#define FWUPD_DEVICE_FLAG_ADD_COUNTERPART_GUIDS (1ull << 35)
 /**
  * FWUPD_DEVICE_FLAG_NO_GUID_MATCHING:
  *
@@ -414,7 +417,7 @@ typedef enum {
  * Since: 1.4.1
  * Deprecated 1.5.8
  */
-#define FWUPD_DEVICE_FLAG_NO_GUID_MATCHING (1llu << 36)
+#define FWUPD_DEVICE_FLAG_NO_GUID_MATCHING (1ull << 36)
 /**
  * FWUPD_DEVICE_FLAG_UPDATABLE_HIDDEN:
  *
@@ -423,7 +426,7 @@ typedef enum {
  *
  * Since: 1.4.1
  */
-#define FWUPD_DEVICE_FLAG_UPDATABLE_HIDDEN (1llu << 37)
+#define FWUPD_DEVICE_FLAG_UPDATABLE_HIDDEN (1ull << 37)
 /**
  * FWUPD_DEVICE_FLAG_SKIPS_RESTART:
  *
@@ -431,7 +434,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_DEVICE_FLAG_SKIPS_RESTART (1llu << 38)
+#define FWUPD_DEVICE_FLAG_SKIPS_RESTART (1ull << 38)
 /**
  * FWUPD_DEVICE_FLAG_HAS_MULTIPLE_BRANCHES:
  *
@@ -439,7 +442,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_DEVICE_FLAG_HAS_MULTIPLE_BRANCHES (1llu << 39)
+#define FWUPD_DEVICE_FLAG_HAS_MULTIPLE_BRANCHES (1ull << 39)
 /**
  * FWUPD_DEVICE_FLAG_BACKUP_BEFORE_INSTALL:
  *
@@ -447,7 +450,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_DEVICE_FLAG_BACKUP_BEFORE_INSTALL (1llu << 40)
+#define FWUPD_DEVICE_FLAG_BACKUP_BEFORE_INSTALL (1ull << 40)
 /**
  * FWUPD_DEVICE_FLAG_MD_SET_ICON:
  *
@@ -456,7 +459,7 @@ typedef enum {
  * Since: 1.5.2
  * Deprecated 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_MD_SET_ICON (1llu << 41)
+#define FWUPD_DEVICE_FLAG_MD_SET_ICON (1ull << 41)
 /**
  * FWUPD_DEVICE_FLAG_WILDCARD_INSTALL:
  *
@@ -468,7 +471,7 @@ typedef enum {
  *
  * Since: 1.6.2
  */
-#define FWUPD_DEVICE_FLAG_WILDCARD_INSTALL (1llu << 42)
+#define FWUPD_DEVICE_FLAG_WILDCARD_INSTALL (1ull << 42)
 /**
  * FWUPD_DEVICE_FLAG_ONLY_VERSION_UPGRADE:
  *
@@ -476,7 +479,7 @@ typedef enum {
  *
  * Since 1.6.2
  */
-#define FWUPD_DEVICE_FLAG_ONLY_VERSION_UPGRADE (1llu << 43)
+#define FWUPD_DEVICE_FLAG_ONLY_VERSION_UPGRADE (1ull << 43)
 /**
  * FWUPD_DEVICE_FLAG_UNREACHABLE:
  *
@@ -485,7 +488,7 @@ typedef enum {
  *
  * Since 1.7.0
  */
-#define FWUPD_DEVICE_FLAG_UNREACHABLE (1llu << 44)
+#define FWUPD_DEVICE_FLAG_UNREACHABLE (1ull << 44)
 /**
  * FWUPD_DEVICE_FLAG_AFFECTS_FDE:
  *
@@ -498,7 +501,7 @@ typedef enum {
  *
  * Since: 1.7.1
  */
-#define FWUPD_DEVICE_FLAG_AFFECTS_FDE (1llu << 45)
+#define FWUPD_DEVICE_FLAG_AFFECTS_FDE (1ull << 45)
 /**
  * FWUPD_DEVICE_FLAG_END_OF_LIFE:
  *
@@ -507,7 +510,7 @@ typedef enum {
  *
  * Since: 1.7.5
  */
-#define FWUPD_DEVICE_FLAG_END_OF_LIFE (1llu << 46)
+#define FWUPD_DEVICE_FLAG_END_OF_LIFE (1ull << 46)
 /**
  * FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD:
  *
@@ -518,7 +521,7 @@ typedef enum {
  *
  * Since: 1.7.6
  */
-#define FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD (1llu << 47)
+#define FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD (1ull << 47)
 /**
  * FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD:
  *
@@ -526,7 +529,7 @@ typedef enum {
  *
  * Since: 1.7.6
  */
-#define FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD (1llu << 48)
+#define FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD (1ull << 48)
 /**
  * FWUPD_DEVICE_FLAG_EMULATED:
  *
@@ -534,7 +537,7 @@ typedef enum {
  *
  * Since: 1.8.11
  */
-#define FWUPD_DEVICE_FLAG_EMULATED (1llu << 49)
+#define FWUPD_DEVICE_FLAG_EMULATED (1ull << 49)
 /**
  * FWUPD_DEVICE_FLAG_EMULATION_TAG:
  *
@@ -542,7 +545,7 @@ typedef enum {
  *
  * Since: 1.8.11
  */
-#define FWUPD_DEVICE_FLAG_EMULATION_TAG (1llu << 50)
+#define FWUPD_DEVICE_FLAG_EMULATION_TAG (1ull << 50)
 /**
  * FWUPD_DEVICE_FLAG_ONLY_EXPLICIT_UPDATES:
  *
@@ -552,7 +555,7 @@ typedef enum {
  *
  * Since: 1.9.3
  */
-#define FWUPD_DEVICE_FLAG_ONLY_EXPLICIT_UPDATES (1llu << 51)
+#define FWUPD_DEVICE_FLAG_ONLY_EXPLICIT_UPDATES (1ull << 51)
 /**
  * FWUPD_DEVICE_FLAG_UNKNOWN:
  *
@@ -584,7 +587,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.1
  */
-#define FWUPD_DEVICE_PROBLEM_SYSTEM_POWER_TOO_LOW (1llu << 0)
+#define FWUPD_DEVICE_PROBLEM_SYSTEM_POWER_TOO_LOW (1ull << 0)
 /**
  * FWUPD_DEVICE_PROBLEM_UNREACHABLE:
  *
@@ -592,7 +595,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.1
  */
-#define FWUPD_DEVICE_PROBLEM_UNREACHABLE (1llu << 1)
+#define FWUPD_DEVICE_PROBLEM_UNREACHABLE (1ull << 1)
 /**
  * FWUPD_DEVICE_PROBLEM_POWER_TOO_LOW:
  *
@@ -600,7 +603,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.1
  */
-#define FWUPD_DEVICE_PROBLEM_POWER_TOO_LOW (1llu << 2)
+#define FWUPD_DEVICE_PROBLEM_POWER_TOO_LOW (1ull << 2)
 /**
  * FWUPD_DEVICE_PROBLEM_UPDATE_PENDING:
  *
@@ -608,7 +611,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.1
  */
-#define FWUPD_DEVICE_PROBLEM_UPDATE_PENDING (1llu << 3)
+#define FWUPD_DEVICE_PROBLEM_UPDATE_PENDING (1ull << 3)
 /**
  * FWUPD_DEVICE_PROBLEM_REQUIRE_AC_POWER:
  *
@@ -616,7 +619,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.1
  */
-#define FWUPD_DEVICE_PROBLEM_REQUIRE_AC_POWER (1llu << 4)
+#define FWUPD_DEVICE_PROBLEM_REQUIRE_AC_POWER (1ull << 4)
 /**
  * FWUPD_DEVICE_PROBLEM_LID_IS_CLOSED:
  *
@@ -624,7 +627,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.1
  */
-#define FWUPD_DEVICE_PROBLEM_LID_IS_CLOSED (1llu << 5)
+#define FWUPD_DEVICE_PROBLEM_LID_IS_CLOSED (1ull << 5)
 /**
  * FWUPD_DEVICE_PROBLEM_IS_EMULATED:
  *
@@ -632,7 +635,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.3
  */
-#define FWUPD_DEVICE_PROBLEM_IS_EMULATED (1llu << 6)
+#define FWUPD_DEVICE_PROBLEM_IS_EMULATED (1ull << 6)
 /**
  * FWUPD_DEVICE_PROBLEM_MISSING_LICENSE:
  *
@@ -640,7 +643,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.6
  */
-#define FWUPD_DEVICE_PROBLEM_MISSING_LICENSE (1llu << 7)
+#define FWUPD_DEVICE_PROBLEM_MISSING_LICENSE (1ull << 7)
 /**
  * FWUPD_DEVICE_PROBLEM_SYSTEM_INHIBIT:
  *
@@ -648,7 +651,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.10
  */
-#define FWUPD_DEVICE_PROBLEM_SYSTEM_INHIBIT (1llu << 8)
+#define FWUPD_DEVICE_PROBLEM_SYSTEM_INHIBIT (1ull << 8)
 /**
  * FWUPD_DEVICE_PROBLEM_UPDATE_IN_PROGRESS:
  *
@@ -656,7 +659,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.11
  */
-#define FWUPD_DEVICE_PROBLEM_UPDATE_IN_PROGRESS (1llu << 9)
+#define FWUPD_DEVICE_PROBLEM_UPDATE_IN_PROGRESS (1ull << 9)
 /**
  * FWUPD_DEVICE_PROBLEM_IN_USE:
  *
@@ -664,7 +667,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.9.1
  */
-#define FWUPD_DEVICE_PROBLEM_IN_USE (1llu << 10)
+#define FWUPD_DEVICE_PROBLEM_IN_USE (1ull << 10)
 /**
  * FWUPD_DEVICE_PROBLEM_DISPLAY_REQUIRED:
  *
@@ -672,7 +675,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.9.6
  */
-#define FWUPD_DEVICE_PROBLEM_DISPLAY_REQUIRED (1llu << 11)
+#define FWUPD_DEVICE_PROBLEM_DISPLAY_REQUIRED (1ull << 11)
 /**
  * FWUPD_DEVICE_PROBLEM_UNKNOWN:
  *
@@ -706,7 +709,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_TRUSTED_PAYLOAD (1llu << 0)
+#define FWUPD_RELEASE_FLAG_TRUSTED_PAYLOAD (1ull << 0)
 /**
  * FWUPD_RELEASE_FLAG_TRUSTED_METADATA:
  *
@@ -714,7 +717,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_TRUSTED_METADATA (1llu << 1)
+#define FWUPD_RELEASE_FLAG_TRUSTED_METADATA (1ull << 1)
 /**
  * FWUPD_RELEASE_FLAG_IS_UPGRADE:
  *
@@ -722,7 +725,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_IS_UPGRADE (1llu << 2)
+#define FWUPD_RELEASE_FLAG_IS_UPGRADE (1ull << 2)
 /**
  * FWUPD_RELEASE_FLAG_IS_DOWNGRADE:
  *
@@ -730,7 +733,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_IS_DOWNGRADE (1llu << 3)
+#define FWUPD_RELEASE_FLAG_IS_DOWNGRADE (1ull << 3)
 /**
  * FWUPD_RELEASE_FLAG_BLOCKED_VERSION:
  *
@@ -738,7 +741,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_BLOCKED_VERSION (1llu << 4)
+#define FWUPD_RELEASE_FLAG_BLOCKED_VERSION (1ull << 4)
 /**
  * FWUPD_RELEASE_FLAG_BLOCKED_APPROVAL:
  *
@@ -746,7 +749,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_BLOCKED_APPROVAL (1llu << 5)
+#define FWUPD_RELEASE_FLAG_BLOCKED_APPROVAL (1ull << 5)
 /**
  * FWUPD_RELEASE_FLAG_IS_ALTERNATE_BRANCH:
  *
@@ -754,7 +757,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.5.0
  */
-#define FWUPD_RELEASE_FLAG_IS_ALTERNATE_BRANCH (1llu << 6)
+#define FWUPD_RELEASE_FLAG_IS_ALTERNATE_BRANCH (1ull << 6)
 /**
  * FWUPD_RELEASE_FLAG_IS_COMMUNITY:
  *
@@ -762,7 +765,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.7.5
  */
-#define FWUPD_RELEASE_FLAG_IS_COMMUNITY (1llu << 7)
+#define FWUPD_RELEASE_FLAG_IS_COMMUNITY (1ull << 7)
 /**
  * FWUPD_RELEASE_FLAG_TRUSTED_REPORT:
  *
@@ -770,7 +773,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.9.1
  */
-#define FWUPD_RELEASE_FLAG_TRUSTED_REPORT (1llu << 8)
+#define FWUPD_RELEASE_FLAG_TRUSTED_REPORT (1ull << 8)
 /**
  * FWUPD_RELEASE_FLAG_UNKNOWN:
  *
@@ -821,7 +824,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_DISABLED (1llu << 0)
+#define FWUPD_PLUGIN_FLAG_DISABLED (1ull << 0)
 /**
  * FWUPD_PLUGIN_FLAG_USER_WARNING:
  *
@@ -829,7 +832,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_USER_WARNING (1llu << 1)
+#define FWUPD_PLUGIN_FLAG_USER_WARNING (1ull << 1)
 /**
  * FWUPD_PLUGIN_FLAG_CLEAR_UPDATABLE:
  *
@@ -838,7 +841,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_CLEAR_UPDATABLE (1llu << 2)
+#define FWUPD_PLUGIN_FLAG_CLEAR_UPDATABLE (1ull << 2)
 /**
  * FWUPD_PLUGIN_FLAG_NO_HARDWARE:
  *
@@ -848,7 +851,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_NO_HARDWARE (1llu << 3)
+#define FWUPD_PLUGIN_FLAG_NO_HARDWARE (1ull << 3)
 /**
  * FWUPD_PLUGIN_FLAG_CAPSULES_UNSUPPORTED:
  *
@@ -857,7 +860,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_CAPSULES_UNSUPPORTED (1llu << 4)
+#define FWUPD_PLUGIN_FLAG_CAPSULES_UNSUPPORTED (1ull << 4)
 /**
  * FWUPD_PLUGIN_FLAG_UNLOCK_REQUIRED:
  *
@@ -866,7 +869,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_UNLOCK_REQUIRED (1llu << 5)
+#define FWUPD_PLUGIN_FLAG_UNLOCK_REQUIRED (1ull << 5)
 /**
  * FWUPD_PLUGIN_FLAG_EFIVAR_NOT_MOUNTED:
  *
@@ -875,7 +878,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_EFIVAR_NOT_MOUNTED (1llu << 6)
+#define FWUPD_PLUGIN_FLAG_EFIVAR_NOT_MOUNTED (1ull << 6)
 /**
  * FWUPD_PLUGIN_FLAG_ESP_NOT_FOUND:
  *
@@ -884,7 +887,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_ESP_NOT_FOUND (1llu << 7)
+#define FWUPD_PLUGIN_FLAG_ESP_NOT_FOUND (1ull << 7)
 /**
  * FWUPD_PLUGIN_FLAG_LEGACY_BIOS:
  *
@@ -893,7 +896,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_LEGACY_BIOS (1llu << 8)
+#define FWUPD_PLUGIN_FLAG_LEGACY_BIOS (1ull << 8)
 /**
  * FWUPD_PLUGIN_FLAG_FAILED_OPEN:
  *
@@ -902,7 +905,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_FAILED_OPEN (1llu << 9)
+#define FWUPD_PLUGIN_FLAG_FAILED_OPEN (1ull << 9)
 /**
  * FWUPD_PLUGIN_FLAG_REQUIRE_HWID:
  *
@@ -910,7 +913,7 @@ typedef enum {
  *
  * Since: 1.5.8
  */
-#define FWUPD_PLUGIN_FLAG_REQUIRE_HWID (1llu << 10)
+#define FWUPD_PLUGIN_FLAG_REQUIRE_HWID (1ull << 10)
 /**
  * FWUPD_PLUGIN_FLAG_KERNEL_TOO_OLD:
  *
@@ -918,7 +921,7 @@ typedef enum {
  *
  * Since: 1.6.2
  */
-#define FWUPD_PLUGIN_FLAG_KERNEL_TOO_OLD (1llu << 11)
+#define FWUPD_PLUGIN_FLAG_KERNEL_TOO_OLD (1ull << 11)
 /**
  * FWUPD_PLUGIN_FLAG_AUTH_REQUIRED:
  *
@@ -927,7 +930,7 @@ typedef enum {
  *
  * Since: 1.6.2
  */
-#define FWUPD_PLUGIN_FLAG_AUTH_REQUIRED (1llu << 12)
+#define FWUPD_PLUGIN_FLAG_AUTH_REQUIRED (1ull << 12)
 /**
  * FWUPD_PLUGIN_FLAG_SECURE_CONFIG:
  *
@@ -936,7 +939,7 @@ typedef enum {
  *
  * Since: 1.8.5
  */
-#define FWUPD_PLUGIN_FLAG_SECURE_CONFIG (1llu << 13)
+#define FWUPD_PLUGIN_FLAG_SECURE_CONFIG (1ull << 13)
 /**
  * FWUPD_PLUGIN_FLAG_MODULAR:
  *
@@ -944,7 +947,7 @@ typedef enum {
  *
  * Since: 1.8.6
  */
-#define FWUPD_PLUGIN_FLAG_MODULAR (1llu << 14)
+#define FWUPD_PLUGIN_FLAG_MODULAR (1ull << 14)
 /**
  * FWUPD_PLUGIN_FLAG_MEASURE_SYSTEM_INTEGRITY:
  *
@@ -952,7 +955,7 @@ typedef enum {
  *
  * Since: 1.8.7
  */
-#define FWUPD_PLUGIN_FLAG_MEASURE_SYSTEM_INTEGRITY (1llu << 15)
+#define FWUPD_PLUGIN_FLAG_MEASURE_SYSTEM_INTEGRITY (1ull << 15)
 /**
  * FWUPD_PLUGIN_FLAG_ESP_NOT_VALID:
  *
@@ -961,7 +964,7 @@ typedef enum {
  *
  * Since: 1.9.3
  */
-#define FWUPD_PLUGIN_FLAG_ESP_NOT_VALID (1llu << 16)
+#define FWUPD_PLUGIN_FLAG_ESP_NOT_VALID (1ull << 16)
 /**
  * FWUPD_PLUGIN_FLAG_READY:
  *
@@ -969,7 +972,7 @@ typedef enum {
  *
  * Since: 1.9.6
  */
-#define FWUPD_PLUGIN_FLAG_READY (1llu << 17)
+#define FWUPD_PLUGIN_FLAG_READY (1ull << 17)
 /**
  * FWUPD_PLUGIN_FLAG_UNKNOWN:
  *
@@ -978,6 +981,14 @@ typedef enum {
  *
  * Since: 1.5.0
  */
+#define FWUPD_PLUGIN_FLAG_TEST_ONLY (1ull << 18)
+/**
+ * FWUPD_PLUGIN_FLAG_TEST_ONLY:
+ *
+ * The plugin is used for virtual devices that exercising daemon flows.
+ *
+ * Since: 1.9.13
+ */
 #define FWUPD_PLUGIN_FLAG_UNKNOWN G_MAXUINT64
 /**
  * FwupdPluginFlags:
@@ -1000,21 +1011,23 @@ typedef guint64 FwupdPluginFlags;
  * @FWUPD_INSTALL_FLAG_IGNORE_POWER:		Ignore requirement of external power source
  *(Deprecated since 1.7.0)
  * @FWUPD_INSTALL_FLAG_NO_SEARCH:		Do not use heuristics when parsing the image
+ * @FWUPD_INSTALL_FLAG_IGNORE_REQUIREMENTS:	Ignore version requirement checks
  *
  * Flags to set when performing the firmware update or install.
  **/
 typedef enum {
-	FWUPD_INSTALL_FLAG_NONE = 0,			 /* Since: 0.7.0 */
-	FWUPD_INSTALL_FLAG_OFFLINE = 1 << 0,		 /* Since: 0.7.0 */
-	FWUPD_INSTALL_FLAG_ALLOW_REINSTALL = 1 << 1,	 /* Since: 0.7.0 */
-	FWUPD_INSTALL_FLAG_ALLOW_OLDER = 1 << 2,	 /* Since: 0.7.0 */
-	FWUPD_INSTALL_FLAG_FORCE = 1 << 3,		 /* Since: 0.7.1 */
-	FWUPD_INSTALL_FLAG_NO_HISTORY = 1 << 4,		 /* Since: 1.0.8 */
-	FWUPD_INSTALL_FLAG_ALLOW_BRANCH_SWITCH = 1 << 5, /* Since: 1.5.0 */
-	FWUPD_INSTALL_FLAG_IGNORE_CHECKSUM = 1 << 6,	 /* Since: 1.5.0 */
-	FWUPD_INSTALL_FLAG_IGNORE_VID_PID = 1 << 7,	 /* Since: 1.5.0 */
-	FWUPD_INSTALL_FLAG_IGNORE_POWER = 1 << 8,	 /* Since: 1.5.0 */
-	FWUPD_INSTALL_FLAG_NO_SEARCH = 1 << 9,		 /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_NONE = 0,			  /* Since: 0.7.0 */
+	FWUPD_INSTALL_FLAG_OFFLINE = 1 << 0,		  /* Since: 0.7.0 */
+	FWUPD_INSTALL_FLAG_ALLOW_REINSTALL = 1 << 1,	  /* Since: 0.7.0 */
+	FWUPD_INSTALL_FLAG_ALLOW_OLDER = 1 << 2,	  /* Since: 0.7.0 */
+	FWUPD_INSTALL_FLAG_FORCE = 1 << 3,		  /* Since: 0.7.1 */
+	FWUPD_INSTALL_FLAG_NO_HISTORY = 1 << 4,		  /* Since: 1.0.8 */
+	FWUPD_INSTALL_FLAG_ALLOW_BRANCH_SWITCH = 1 << 5,  /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_IGNORE_CHECKSUM = 1 << 6,	  /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_IGNORE_VID_PID = 1 << 7,	  /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_IGNORE_POWER = 1 << 8,	  /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_NO_SEARCH = 1 << 9,		  /* Since: 1.5.0 */
+	FWUPD_INSTALL_FLAG_IGNORE_REQUIREMENTS = 1 << 10, /* Since: 1.9.21 */
 	/*< private >*/
 	FWUPD_INSTALL_FLAG_LAST
 } FwupdInstallFlags;
